@@ -2,9 +2,12 @@
 
 ;;; Code:
 
-(custom-add-loads 'tools '("speedbar"))
+(autoload 'custom-add-loads "cus-load")
+
 (custom-add-loads 'speedbar '("speedbar"))
 (custom-add-loads 'tags '("speedbar"))
 (custom-add-loads 'faces '("speedbar"))
+(custom-add-loads 'speedbar-faces '("speedbar"))
+(custom-add-loads 'speedbar-vc '("speedbar"))
 
 ;;; custom-load.el ends here
